@@ -1,7 +1,10 @@
 test_that("Source code should not have things on TODO list", {
   expect_false({
-    files_to_check <- list.files("../..", pattern = ".r$|NEWS|DESCRIPTION|README", recursive = T, full.names = T)
-    files_to_check <- files_to_check[!endsWith(files_to_check, "test_dev.r")]
+    files_to_check <-
+      list.files(system.file(package = "CopernicusMarine"),
+                 pattern = "[.]r$|NEWS|DESCRIPTION|README", recursive = TRUE, full.names = TRUE)
+    files_to_check <- files_to_check[!endsWith(files_to_check, "test_dev.r") &
+                                       !endsWith(files_to_check, ".png")]
     any(
       unlist(
         lapply(files_to_check, function(file) {
